==> jvim_3.0-2.0.orig.tar.gz: jvim-3.0-2.0.orig/src/winjmenu.h <==
/* Win32 GUI mode param */
#define	IDM_EXTEND		0x100
#define IDM_CANCEL		0x110
#define IDM_EXIT		0x120
#define IDM_VER			0x130
#define IDM_VER2		0x131
#define IDM_HELP		0x140
#define IDM_NFILE		0x150
#define IDM_PFILE		0x160
#define IDM_TAIL		0x170
#define IDM_OPEN		0x200
#define IDM_SFILE		0x201
#define IDM_AFILE		0x202
#define IDM_NEW			0x210
#define IDM_FILE		0x220
#define IDM_CLICK		0x230
#define IDM_PRINT		0x240
#define IDM_SAVE		0x300
#define IDM_SBAR		0x310
#define IDM_UNICODE		0x320
#define IDM_TRAY		0x330
#define IDM_MOUSE		0x340
#define IDM_PRINTSET	0x350
#define	IDM_MENU		0x360
#define IDM_YANK		0x400
#define IDM_DELETE		0x410
#define IDM_PASTE		0x420
#define IDM_FONT		0x500
#define IDM_BDF			0x510
#define IDM_BDFONOFF	0x511
#define IDM_FWHITE		0x520
#define IDM_FBLACK		0x521
#define IDM_FBLUE		0x522
#define IDM_FCOLOR		0x523
#define IDM_BWHITE		0x530
#define IDM_BBLACK		0x531
#define IDM_BCOLOR		0x532
#define IDM_TBCOLOR		0x540
#define IDM_SOCOLOR		0x541
#define IDM_TICOLOR		0x542
#define IDM_DELCOLOR	0x543
#define IDM_BITMAP		0x550
#define IDM_BITMAPONOFF	0x551
#define IDM_BITMAPUP	0x552
#define IDM_BITMAPDOWN	0x553
#define IDM_BITMIXONOFF	0x554
#define IDM_BITMIXUP	0x555
#define IDM_BITMIXDOWN	0x556
#define IDM_WAVE		0x560
#define IDM_WAVEONOFF	0x561
#define IDM_CONFS		0x600
#define IDM_CONFUP		0x601
#define IDM_CONFDOWN	0x602
#define IDM_CONF0		0x610
#define IDM_CONF1		0x611
#define IDM_CONF2		0x612
#define IDM_CONF3		0x613
#define IDM_CONF4		0x614
#define IDM_CONF5		0x615
#define IDM_CONF6		0x616
#define IDM_CONF7		0x617
#define IDM_CONF8		0x618
#define IDM_CONF9		0x619
#define IDM_COMDS		0x620
#define IDM_COMD0		0x630
#define IDM_COMD1		0x631
#define IDM_COMD2		0x632
#define IDM_COMD3		0x633
#define IDM_COMD4		0x634
#define IDM_COMD5		0x635
#define IDM_COMD6		0x636
#define IDM_COMD7		0x637
#define IDM_COMD8		0x638
#define IDM_COMD9		0x639
#define	IDM_COMB		0x640

==> jvim_3.0-2.1a.orig.tar.gz: jvim-3.0-2.1a.orig/src/winjmenu.h <==
/* Win32 GUI mode param */
#define	IDM_EXTEND		0x100
#define IDM_CANCEL		0x110
#define IDM_EXIT		0x120
#define IDM_VER			0x130
#define IDM_VER2		0x131
#define IDM_HELP		0x140
#define IDM_NFILE		0x150
#define IDM_PFILE		0x160
#define IDM_TAIL		0x170
#define IDM_OPEN		0x200
#define IDM_SFILE		0x201
#define IDM_AFILE		0x202
#define IDM_NEW			0x210
#define IDM_FILE		0x220
#define IDM_CLICK		0x230
#define IDM_PRINT		0x240
#define IDM_SAVE		0x300
#define IDM_SBAR		0x310
#define IDM_UNICODE		0x320
#define IDM_TRAY		0x330
#define IDM_MOUSE		0x340
#define IDM_PRINTSET	0x350
#define	IDM_MENU		0x360
#define	IDM_NT106		0x370
#define IDM_SHARE		0x380
#define IDM_FADEOUT		0x390
#define IDM_ONEWIN		0x3A0
#define IDM_YANK		0x400
#define IDM_DELETE		0x410
#define IDM_PASTE		0x420
#define IDM_FONT		0x500
#define IDM_LSPACE		0x501
#define IDM_BDF			0x510
#define IDM_BDFONOFF	0x511
#define IDM_FWHITE		0x520
#define IDM_FBLACK		0x521
#define IDM_FBLUE		0x522
#define IDM_FCOLOR		0x523
#define IDM_BWHITE		0x530
#define IDM_BBLACK		0x531
#define IDM_BCOLOR		0x532
#define IDM_TBCOLOR		0x540
#define IDM_SOCOLOR		0x541
#define IDM_TICOLOR		0x542
#define IDM_DELCOLOR	0x543
#define IDM_BITMAP		0x550
#define IDM_BITMAPONOFF	0x551
#define IDM_BITMAPUP	0x552
#define IDM_BITMAPDOWN	0x553
#define IDM_BITSIZEUP	0x555
#define IDM_BITSIZEDOWN	0x556
#define IDM_TRANSUP		0x557
#define IDM_TRANSDOWN	0x558
#define IDM_WAVE		0x560
#define IDM_WAVEONOFF	0x561
#define IDM_CONFS		0x600
#define IDM_CONFUP		0x601
#define IDM_CONFDOWN	0x602
#define IDM_CONF0		0x610
#define IDM_CONF1		0x611
#define IDM_CONF2		0x612
#define IDM_CONF3		0x613
#define IDM_CONF4		0x614
#define IDM_CONF5		0x615
#define IDM_CONF6		0x616
#define IDM_CONF7		0x617
#define IDM_CONF8		0x618
#define IDM_CONF9		0x619
#define IDM_COMDS		0x620
#define IDM_COMD0		0x630
#define IDM_COMD1		0x631
#define IDM_COMD2		0x632
#define IDM_COMD3		0x633
#define IDM_COMD4		0x634
#define IDM_COMD5		0x635
#define IDM_COMD6		0x636
#define IDM_COMD7		0x637
#define IDM_COMD8		0x638
#define IDM_COMD9		0x639
#define	IDM_COMB		0x640
